==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/fr.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Activités",
    "Error loading activities" : "Erreur lors du chargement des activités",
    "No activities" : "Aucune activité",
    "Load more activities" : "Charger plus d'activités",
    "Copied!" : "Copié !",
    "Not supported!" : "Non pris en charge !",
    "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restreint)",
    "in {path}" : "dans {path}",
    "This stream will show events like additions, changes & shares" : "Ce flux liste les événements tels que les ajouts, les modifications et les partages",
    "There are no events for this filter" : "Il n'y a pas d'événement pour ce filtre",
    "Today" : "Aujourd'hui",
    "Yesterday" : "Hier",
    "Activity" : "Activité",
    "Personal activity feed for %s" : "Flux d'activité personnel de %s",
    "Your feed URL is invalid" : "Votre URL de fil d’activité n'est pas valide",
    "Your settings have been updated." : "Vos paramètres ont été mis à jour.",
    "Mail" : "Mail",
    "Stream" : "Flux",
    "All activities" : "Toutes les activités",
    "By others" : "Des autres",
    "By you" : "De vous",
    "\"remote user\"" : "\"utilisateur distant\"",
    "Activity notification" : "Notification d'activité",
    ", " : ", ",
    "%s and %s" : "%s et %s",
    "Hello %s," : "Bonjour %s,",
    "You are receiving this email because the following things happened at %s" : "Vous recevez ce message car l'activité suivante a eu lieu sur %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* et %n autre","* et %n autres"],
    "List your own actions in the stream" : "Lister vos propres actions dans le flux",
    "Notify about your own actions via email" : "M'informer de mes propres actions par courriel",
    "You need to set up your email address before you can receive notification emails." : "Il est nécessaire de configurer une adresse courriel avant de pouvoir recevoir les notifications par courriel.",
    "Send emails:" : "Envoyer des courriels :",
    "Hourly" : "Toutes les heures",
    "Daily" : "Quotidiennement",
    "Weekly" : "Chaque semaine",
    "Activity feed" : "Fil d'activité",
    "Enable RSS feed" : "Activer les flux RSS",
    "No activity yet" : "Pas d'activité pour le moment",
    "No more events to load" : "Plus aucun événement à charger",
    "Files" : "Fichiers"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/fr.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Activités",
    "An error occurred while loading activities" : "Une erreur est survenue lors du chargement des activités",
    "No activity yet" : "Pas d'activité pour le moment",
    "Load more activities" : "Charger plus d'activités",
    "Copied!" : "Copié !",
    "Not supported!" : "Non pris en charge !",
    "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restreint)",
    "in {path}" : "dans {path}",
    "This stream will show events like additions, changes & shares" : "Ce flux liste les événements tels que les ajouts, les modifications et les partages",
    "There are no events for this filter" : "Il n'y a aucun événement pour ce filtre",
    "Today" : "Aujourd'hui",
    "Yesterday" : "Hier",
    "Personal activity feed for %s" : "Flux d'activité personnel de %s",
    "Your feed URL is invalid" : "Votre URL de fil d’activité n'est pas valide",
    "Your settings have been updated." : "Vos paramètres ont été mis à jour.",
    "Settings have been updated." : "Les paramètres ont été mis à jour.",
    "Mail" : "Courriel",
    "Stream" : "Flux",
    "All activities" : "Toutes les activités",
    "By others" : "Des autres",
    "By you" : "De vous",
    "\"remote user\"" : "\"utilisateur distant\"",
    "Hello %s" : "Bonjour %s",
    "Hello %s," : "Bonjour %s,",
    "There was some activity at %s" : "Il y a eu quelques activités à %s",
    "_and %n more _::_and %n more _" : ["et %n autre","et %n autres"],
    "Activity notification" : "Notification d'activité",
    ", " : ", ",
    "%s and %s" : "%s et %s",
    "Activity" : "Activité",
    "Activity feed" : "Fil d'activité",
    "Configure the default activity settings for new users." : "Configurez les paramètres d'activité par défaut pour les nouveaux utilisateurs.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Choisissez pour quelles activités vous souhaitez obtenir une notification par e-mail et qui devrait apparaître dans le flux d'activité.",
    "List your own actions in the stream" : "Lister vos propres actions dans le flux",
    "Notify about your own actions via email" : "M'informer de mes propres actions par courriel",
    "You need to set up your email address before you can receive notification emails." : "Vous devez configurer une adresse de courriel pour pouvoir recevoir des notifications par courriel.",
    "Send emails:" : "Envoyer des courriels :",
    "Hourly" : "Toutes les heures",
    "Daily" : "Quotidiennement",
    "Weekly" : "Chaque semaine",
    "Settings" : "Paramètres",
    "Enable RSS feed" : "Activer les flux RSS",
    "No more events to load" : "Plus aucun événement à charger",
    "Files" : "Fichiers"
},
"nplurals=2; plural=(n > 1);");
